@@ -20,15 +20,15 @@
 
 #include "host.h"
 
-/**----------------------------------------------------------------------------
+/*-----------------------------------------------------------------------------
           Include Files and Type Defines
-----------------------------------------------------------------------------**/
-#define BITSINLONG      32       /*no of bits in a long */
+-----------------------------------------------------------------------------*/
+#define BITSINLONG      32       /**< no of bits in a long */
 typedef uinT32 *BIT_VECTOR;
 
-/**----------------------------------------------------------------------------
+/*-----------------------------------------------------------------------------
           Public Function Prototypes
-----------------------------------------------------------------------------**/
+-----------------------------------------------------------------------------*/
 #define zero_all_bits(array,length) \
 {\
 	register int			index;						/*temporary index*/\
