@@ -96,11 +96,11 @@ class DLLSYM CLIST
     void shallow_clear();  //clear list but dont
     //delete data elements
 
-    BOOL8 empty() {  //is list empty?
+    bool empty() {  //is list empty?
       return !last;
     }
 
-    BOOL8 singleton() {
+    bool singleton() {
       return last != NULL ? (last == last->next) : FALSE;
     }
 
@@ -165,13 +165,13 @@ class DLLSYM CLIST_ITERATOR
   CLIST_LINK *prev;              //prev element
   CLIST_LINK *current;           //current element
   CLIST_LINK *next;              //next element
-  BOOL8 ex_current_was_last;     //current extracted
+  bool ex_current_was_last;     //current extracted
   //was end of list
-  BOOL8 ex_current_was_cycle_pt; //current extracted
+  bool ex_current_was_cycle_pt; //current extracted
   //was cycle point
   CLIST_LINK *cycle_pt;          //point we are cycling
   //the list to.
-  BOOL8 started_cycling;         //Have we moved off
+  bool started_cycling;         //Have we moved off
   //the start?
 
   CLIST_LINK *extract_sublist(                            //from this current...
@@ -229,7 +229,7 @@ class DLLSYM CLIST_ITERATOR
 
     void mark_cycle_pt();  //remember current
 
-    BOOL8 empty() {  //is list empty?
+    bool empty() {  //is list empty?
     #ifndef NDEBUG
       if (!list)
         NO_LIST.error ("CLIST_ITERATOR::empty", ABORT, NULL);
@@ -237,15 +237,15 @@ class DLLSYM CLIST_ITERATOR
       return list->empty ();
     }
 
-    BOOL8 current_extracted() {  //current extracted?
+    bool current_extracted() {  //current extracted?
       return !current;
     }
 
-    BOOL8 at_first();  //Current is first?
+    bool at_first();  //Current is first?
 
-    BOOL8 at_last();  //Current is last?
+    bool at_last();  //Current is last?
 
-    BOOL8 cycled_list();  //Completed a cycle?
+    bool cycled_list();  //Completed a cycle?
 
     void add_to_end(                  //add at end &
                     void *new_data);  //dont move
@@ -695,7 +695,7 @@ inline void CLIST_ITERATOR::mark_cycle_pt() {
  *
  **********************************************************************/
 
-inline BOOL8 CLIST_ITERATOR::at_first() {
+inline bool CLIST_ITERATOR::at_first() {
   #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("CLIST_ITERATOR::at_first", ABORT, NULL);
@@ -717,7 +717,7 @@ inline BOOL8 CLIST_ITERATOR::at_first() {
  *
  **********************************************************************/
 
-inline BOOL8 CLIST_ITERATOR::at_last() {
+inline bool CLIST_ITERATOR::at_last() {
   #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("CLIST_ITERATOR::at_last", ABORT, NULL);
@@ -739,7 +739,7 @@ inline BOOL8 CLIST_ITERATOR::at_last() {
  *
  **********************************************************************/
 
-inline BOOL8 CLIST_ITERATOR::cycled_list() {
+inline bool CLIST_ITERATOR::cycled_list() {
   #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("CLIST_ITERATOR::cycled_list", ABORT, NULL);
