@@ -110,11 +110,11 @@ class DLLSYM ELIST2
       void (*zapper) (ELIST2_LINK *));
     //ptr to zapper functn
 
-    BOOL8 empty() {  //is list empty?
+    bool empty() {  //is list empty?
       return !last;
     }
 
-    BOOL8 singleton() {
+    bool singleton() {
       return last ? (last == last->next) : FALSE;
     }
 
@@ -179,13 +179,13 @@ class DLLSYM ELIST2_ITERATOR
   ELIST2_LINK *prev;             //prev element
   ELIST2_LINK *current;          //current element
   ELIST2_LINK *next;             //next element
-  BOOL8 ex_current_was_last;     //current extracted
+  bool ex_current_was_last;     //current extracted
   //was end of list
-  BOOL8 ex_current_was_cycle_pt; //current extracted
+  bool ex_current_was_cycle_pt; //current extracted
   //was cycle point
   ELIST2_LINK *cycle_pt;         //point we are cycling
   //the list to.
-  BOOL8 started_cycling;         //Have we moved off
+  bool started_cycling;         //Have we moved off
   //the start?
 
   ELIST2_LINK *extract_sublist(                             //from this current...
@@ -246,7 +246,7 @@ class DLLSYM ELIST2_ITERATOR
 
     void mark_cycle_pt();  //remember current
 
-    BOOL8 empty() {  //is list empty?
+    bool empty() {  //is list empty?
     #ifndef NDEBUG
       if (!list)
         NO_LIST.error ("ELIST2_ITERATOR::empty", ABORT, NULL);
@@ -254,15 +254,15 @@ class DLLSYM ELIST2_ITERATOR
       return list->empty ();
     }
 
-    BOOL8 current_extracted() {  //current extracted?
+    bool current_extracted() {  //current extracted?
       return !current;
     }
 
-    BOOL8 at_first();  //Current is first?
+    bool at_first();  //Current is first?
 
-    BOOL8 at_last();  //Current is last?
+    bool at_last();  //Current is last?
 
-    BOOL8 cycled_list();  //Completed a cycle?
+    bool cycled_list();  //Completed a cycle?
 
     void add_to_end(                         //add at end &
                     ELIST2_LINK *new_link);  //dont move
@@ -750,7 +750,7 @@ inline void ELIST2_ITERATOR::mark_cycle_pt() {
  *
  **********************************************************************/
 
-inline BOOL8 ELIST2_ITERATOR::at_first() {
+inline bool ELIST2_ITERATOR::at_first() {
   #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::at_first", ABORT, NULL);
@@ -772,7 +772,7 @@ inline BOOL8 ELIST2_ITERATOR::at_first() {
  *
  **********************************************************************/
 
-inline BOOL8 ELIST2_ITERATOR::at_last() {
+inline bool ELIST2_ITERATOR::at_last() {
   #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::at_last", ABORT, NULL);
@@ -794,7 +794,7 @@ inline BOOL8 ELIST2_ITERATOR::at_last() {
  *
  **********************************************************************/
 
-inline BOOL8 ELIST2_ITERATOR::cycled_list() {
+inline bool ELIST2_ITERATOR::cycled_list() {
   #ifndef NDEBUG
   if (!this)
     NULL_OBJECT.error ("ELIST2_ITERATOR::cycled_list", ABORT, NULL);
