@@ -90,7 +90,6 @@ typedef FEATURE_DESC_STRUCT *FEATURE_DESC;
 typedef struct fxs
 {
   FX_FUNC Extractor;             /* func to extract features */
-  VOID_FUNC InitExtractorVars;   /* func to init fx controls */
 } FEATURE_EXT_STRUCT;
 
 /*----------------------------------------------------------------------
@@ -111,23 +110,19 @@ are as follows:
 
 DefineFeature (Name, NumLinear, NumCircular,
           MinFeatPerChar, MaxFeatPerChar,
-          LongName, ShortName, ParamName,
-      Extractor, Displayer,
-      ComputeExtraPenalty,
-      InitExtractor, InitExtractorVars, TweekExtractorVars)
+          LongName, ShortName, ParamName)
 ----------------------------------------------------------------------*/
 #define DefineFeature(Name, NL, NC, Min, Max, LN, SN, PN)		\
 FEATURE_DESC_STRUCT Name = {						\
 	((NL) + (NC)), NL, NC, Min, Max, LN, SN, PN};
-#define DefineFeatureExt(Name, E, IEV) FEATURE_EXT_STRUCT Name = {E, IEV};
+
+#define DefineFeatureExt(Name, E) FEATURE_EXT_STRUCT Name = {E};
 
 /*----------------------------------------------------------------------
         Generic routines that work for all feature types
 ----------------------------------------------------------------------*/
 BOOL8 AddFeature(FEATURE_SET FeatureSet, FEATURE Feature);
 
-void DefaultInitFXVars();
-
 void FreeFeature(FEATURE Feature);
 
 void FreeFeatureSet(FEATURE_SET FeatureSet);
