@@ -26,8 +26,8 @@
 // Permute the given char_choices using a character level n-gram model and
 // return the best word choice found. The given dawg is used to determine
 // which choices are contained in the dictionary.
-A_CHOICE *ngram_permute_and_select(CHOICES_LIST char_choices,
+/*A_CHOICE *ngram_permute_and_select(CHOICES_LIST char_choices,
                                    float rating_limit,
-                                   EDGE_ARRAY dawg);
+                                   const Dawg *dawg);*/
 
 #endif  // PERMNGRAM_H
