@@ -25,8 +25,10 @@
 #include          "normalis.h"
 #include          "stepblob.h"
 
-class PBLOB:public ELIST_LINK
-{
+const int kBlnXHeight = 128;  // x-height for baseline normalisation
+const int kBlnBaselineOffset = 64;  // offset for baseline normalization
+
+class PBLOB : public ELIST_LINK {
   public:
     PBLOB() {
     }                            //empty constructor
@@ -62,6 +64,7 @@ class PBLOB:public ELIST_LINK
     void scale(                    // scale blob
                const FCOORD vec);  // by FLOAT vector
     void rotate();  // Rotate 90 deg anti
+    void rotate(const FCOORD& rotation);  // Rotate by given rotation.
 
     void prep_serialise() {  //set ptrs to counts
       outlines.prep_serialise ();
